==> huaweicloudsdkcc-3.1.99-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/instance_domain_id.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InstanceDomainId:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_domain_id': 'str'
    }

    attribute_map = {
        'instance_domain_id': 'instance_domain_id'
    }

    def __init__(self, instance_domain_id=None):
        """InstanceDomainId

        The model defined in huaweicloud sdk

        :param instance_domain_id: 实例所属帐号ID。
        :type instance_domain_id: str
        """
        
        

        self._instance_domain_id = None
        self.discriminator = None

        if instance_domain_id is not None:
            self.instance_domain_id = instance_domain_id

    @property
    def instance_domain_id(self):
        """Gets the instance_domain_id of this InstanceDomainId.

        实例所属帐号ID。

        :return: The instance_domain_id of this InstanceDomainId.
        :rtype: str
        """
        return self._instance_domain_id

    @instance_domain_id.setter
    def instance_domain_id(self, instance_domain_id):
        """Sets the instance_domain_id of this InstanceDomainId.

        实例所属帐号ID。

        :param instance_domain_id: The instance_domain_id of this InstanceDomainId.
        :type instance_domain_id: str
        """
        self._instance_domain_id = instance_domain_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceDomainId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcc-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/instance_domain_id.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class InstanceDomainId:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_domain_id': 'str'
    }

    attribute_map = {
        'instance_domain_id': 'instance_domain_id'
    }

    def __init__(self, instance_domain_id=None):
        """InstanceDomainId

        The model defined in huaweicloud sdk

        :param instance_domain_id: 网络实例（VPC，VGW）所属账号ID。
        :type instance_domain_id: str
        """
        
        

        self._instance_domain_id = None
        self.discriminator = None

        if instance_domain_id is not None:
            self.instance_domain_id = instance_domain_id

    @property
    def instance_domain_id(self):
        """Gets the instance_domain_id of this InstanceDomainId.

        网络实例（VPC，VGW）所属账号ID。

        :return: The instance_domain_id of this InstanceDomainId.
        :rtype: str
        """
        return self._instance_domain_id

    @instance_domain_id.setter
    def instance_domain_id(self, instance_domain_id):
        """Sets the instance_domain_id of this InstanceDomainId.

        网络实例（VPC，VGW）所属账号ID。

        :param instance_domain_id: The instance_domain_id of this InstanceDomainId.
        :type instance_domain_id: str
        """
        self._instance_domain_id = instance_domain_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceDomainId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
